# logpandas

[![](https://img.shields.io/pypi/v/logpandas.svg)](https://pypi.python.org/pypi/logpandas)

Parse various logfiles commonly found in `/var/log` as [Pandas](https://pandas.pydata.org/) DataFrames.

# Installation

To install the package, type:

```bash
pip install logpandas
```

# Usage

For more information on the command-line interface, type:

```
logpandas --help
```

```
usage: logpandas [-h] input_filepath output_filepath

positional arguments:
  input_filepath
  output_filepath

optional arguments:
  -h, --help       show this help message and exit
```

# License

This project is licensed under the MIT license. See the [LICENSE](LICENSE) for details.
